@@ -8,7 +8,7 @@ class RemoteSpecView(BaseView):
     def __init__(self, name: str, resources: Sequence, title: str = "", description: str = "", attribution: str = "",
                  spec_type: str = "simple", spec: dict = None, type: str = "", group: str = "",
                  series: Sequence = list(), row_limit: int = 500, metadata: dict = None):
-        super().__init__(name=name, resources=resources, description=description, attribution=attribution,
+        super().__init__(name=name, resources=resources, title=title, description=description, attribution=attribution,
                          spec_type=spec_type, spec=spec, type=type, group=group,
                          series=series, row_limit=row_limit, metadata=metadata)
 
